@@ -1,6 +1,6 @@
 # coding:utf-8
 from tools_hjh.ThreadPool import ThreadPool
-from tools_hjh.other import remove_leading_space
+from tools_hjh.Tools import remove_leading_space
 
 
 class DBConn:
