@@ -617,7 +617,7 @@ class OracleTools:
             sid = ''
             service_name = ''
             tns_name = tns_s.split('=')[0]
-            tns_s = tns_s.replace(tns_name, '')  # 避免tns_name里面含有关键字
+            tns_s = tns_s.replace(tns_name + '=', '')  # 避免tns_name里面含有关键字
             if 'SID=' in tns_s:
                 sid = tns_s.split('SID=')[1].split(')')[0]
             elif 'SERVICE_NAME=' in tns_s:
